@@ -24,7 +24,7 @@
 
 class ExamplePart : public KoDocument
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     ExamplePart( TQWidget *parentWidget = 0, const char *widgetName = 0, TQObject* parent = 0, const char* name = 0, bool singleViewMode = false );
