@@ -134,7 +134,7 @@ bool AmiProParser::process( const TQString& filename )
     return setResult( FileError );
 
   TQTextStream stream;
-  stream.setDevice( TQT_TQIODEVICE(&in) );
+  stream.setDevice( &in );
 
   // the first should be "[ver]"
   line = stream.readLine();
