@@ -27,7 +27,7 @@ class TQDomElement;
 
 class MSWordImport : public KoFilter
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     MSWordImport( KoFilter* parent, const char* name, const TQStringList& );
