@@ -79,7 +79,7 @@ public:
 
 class Dialog : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 public:
     Dialog(uint nbPages, bool isEncrypted, TQWidget *parent);
