@@ -56,7 +56,7 @@ void VColorSlider::init()
 	TQHBoxLayout *layout = new TQHBoxLayout( this, 3 );
 
 	m_label = new TQLabel( this );
-	m_gradientSelect = new KGradientSelector( Qt::Horizontal, this );
+	m_gradientSelect = new KGradientSelector( TQt::Horizontal, this );
 	m_spinBox = new KIntSpinBox( this );
 
 	layout->addWidget( m_label );
@@ -67,8 +67,8 @@ void VColorSlider::init()
 	setMinValue( 0 );
 	setMaxValue( 255 );
 
-	connect( m_spinBox, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( updateFrom_spinBox( int ) ) );
-	connect( m_gradientSelect, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( updateFrom_gradientSelect( int ) ) );
+	connect( m_spinBox, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( updateFrom_spinBox( int ) ) );
+	connect( m_gradientSelect, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( updateFrom_gradientSelect( int ) ) );
 
 	m_gradientSelect->installEventFilter( this );
 
@@ -114,9 +114,9 @@ void VColorSlider::updateFrom_spinBox( int value )
 {
 	if ( value != m_gradientSelect->value() )
 	{
-		disconnect( m_gradientSelect, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( updateFrom_gradientSelect( int ) ) );
+		disconnect( m_gradientSelect, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( updateFrom_gradientSelect( int ) ) );
 		m_gradientSelect->setValue( (m_maxValue - value) + m_minValue );
-		connect( m_gradientSelect, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( updateFrom_gradientSelect( int ) ) );
+		connect( m_gradientSelect, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( updateFrom_gradientSelect( int ) ) );
 		emit valueChanged( value );
 	}
 }
@@ -126,9 +126,9 @@ void VColorSlider::updateFrom_gradientSelect( int value )
 	value = (m_maxValue - value) + m_minValue;
 	if ( value != m_spinBox->value() )
 	{
-		disconnect( m_spinBox, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( updateFrom_spinBox( int ) ) );
+		disconnect( m_spinBox, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( updateFrom_spinBox( int ) ) );
 		m_spinBox->setValue( value );
-		connect( m_spinBox, TQT_SIGNAL( valueChanged ( int ) ), this, TQT_SLOT( updateFrom_spinBox( int ) ) );
+		connect( m_spinBox, TQ_SIGNAL( valueChanged ( int ) ), this, TQ_SLOT( updateFrom_spinBox( int ) ) );
 		emit valueChanged( value );
 	}
 }
