@@ -693,7 +693,7 @@ bool KChartPart::showWizard( TQString &dataArea )
 {
     KChartWizard  *wizard = new KChartWizard( this, m_parentWidget, "wizard" );
 
-    connect( wizard, TQT_SIGNAL(finished()), this, TQT_SLOT(slotModified()) );
+    connect( wizard, TQ_SIGNAL(finished()), this, TQ_SLOT(slotModified()) );
 
     wizard->setDataArea( dataArea );
 
