@@ -634,12 +634,12 @@ public slots:
         }
 
 
-    void setShadowPattern( Qt::BrushStyle style ) {
+    void setShadowPattern( TQt::BrushStyle style ) {
         _shadowPattern = style;
         emit changed();
     }
 
-    Qt::BrushStyle shadowPattern() const {
+    TQt::BrushStyle shadowPattern() const {
         return _shadowPattern;
     }
 
@@ -669,13 +669,13 @@ public slots:
         }
 
 
-    void setOutlineDataLineStyle( Qt::PenStyle style )
+    void setOutlineDataLineStyle( TQt::PenStyle style )
         {
             _outlineDataLineStyle = style;
             emit changed();
         }
 
-    Qt::PenStyle outlineDataLineStyle() const
+    TQt::PenStyle outlineDataLineStyle() const
         {
             return _outlineDataLineStyle;
         }
@@ -750,7 +750,7 @@ public slots:
                                uint chart = KDCHART_ALL_CHARTS );
 
     void setDataValuesColors( const TQColor* color = KDCHART_DATA_VALUE_AUTO_COLOR,
-                              const TQBrush& background = TQBrush(Qt::NoBrush),
+                              const TQBrush& background = TQBrush(TQt::NoBrush),
                               uint chart = KDCHART_ALL_CHARTS );
 
     // Note if you change the parameters here, then you must also change them in wrappers/KDChartParametersWrapper.h
@@ -1151,9 +1151,9 @@ public slots:
             return _lineColor;
         }
 
-    void setLineStyle( Qt::PenStyle style, uint dataset=KDCHART_GLOBAL_LINE_STYLE );
+    void setLineStyle( TQt::PenStyle style, uint dataset=KDCHART_GLOBAL_LINE_STYLE );
 
-    Qt::PenStyle lineStyle( uint dataset=KDCHART_GLOBAL_LINE_STYLE ) const;
+    TQt::PenStyle lineStyle( uint dataset=KDCHART_GLOBAL_LINE_STYLE ) const;
 
 
     void setThreeDLines( bool threeD ) {
@@ -1867,13 +1867,13 @@ public slots:
             return _legendPosition;
         }
 
-    void setLegendOrientation( Qt::Orientation orientation )
+    void setLegendOrientation( TQt::Orientation orientation )
         {
             _legendOrientation = orientation;
             emit changed();
         }
 
-    Qt::Orientation legendOrientation() const
+    TQt::Orientation legendOrientation() const
         {
             return _legendOrientation;
         }
@@ -2544,14 +2544,14 @@ private:
     uint _maxDatasetSourceMode;
     KDChartPropertySetList _propertySetList;
     double _shadowBrightnessFactor;
-    Qt::BrushStyle _shadowPattern;
+    TQt::BrushStyle _shadowPattern;
     bool _threeDShadowColors;
     uint _maxDatasetColor;
     TQMap < uint, TQColor > _dataColorsShadow1;
     TQMap < uint, TQColor > _dataColorsShadow2;
     TQColor _outlineDataColor;
     uint _outlineDataLineWidth;
-    Qt::PenStyle _outlineDataLineStyle;
+    TQt::PenStyle _outlineDataLineStyle;
 
 
     struct PrintDataValuesSettings {
@@ -2613,8 +2613,8 @@ private:
     TQSize _lineMarkerSize;
     TQColor _lineColor;
     int _lineWidth;
-    Qt::PenStyle _lineStyle;
-    typedef TQMap<uint, Qt::PenStyle> LineStyleMap;
+    TQt::PenStyle _lineStyle;
+    typedef TQMap<uint, TQt::PenStyle> LineStyleMap;
     LineStyleMap _datasetLineStyles;
     AreaChartSubType _areaChartSubType;
     AreaLocation _areaLocation;
@@ -2701,7 +2701,7 @@ private:
     // LEGENDS
 
     LegendPosition _legendPosition;
-    Qt::Orientation _legendOrientation;
+    TQt::Orientation _legendOrientation;
     bool _legendShowLines;
     LegendSource _legendSource;
     TQMap < int, TQString > _legendText;
