@@ -108,14 +108,14 @@ private:
     void setG( TQWidget *w, int p, int s, bool isSplitter = FALSE );
 
     TQCOORD pick( const TQPoint &p ) const
-    { return orient ==Qt::Horizontal ? p.x() : p.y(); }
+    { return orient ==TQt::Horizontal ? p.x() : p.y(); }
     TQCOORD pick( const TQSize &s ) const
-    { return orient ==Qt::Horizontal ? s.width() : s.height(); }
+    { return orient ==TQt::Horizontal ? s.width() : s.height(); }
 
     TQCOORD trans( const TQPoint &p ) const
-    { return orient ==Qt::Vertical ? p.x() : p.y(); }
+    { return orient ==TQt::Vertical ? p.x() : p.y(); }
     TQCOORD trans( const TQSize &s ) const
-    { return orient ==Qt::Vertical ? s.width() : s.height(); }
+    { return orient ==TQt::Vertical ? s.width() : s.height(); }
 
     TQSplitterData *data;
 
