@@ -33,8 +33,8 @@ KexiContextHelp::KexiContextHelp(KexiMainWindow *view, TQWidget *parent)
 	kdDebug()<<"KexiContextHelp::KexiContextHelp()"<<endl;
 	setCaption(i18n("Context Help"));
 	setIcon(SmallIcon("help"));
-	connect(this,TQT_SIGNAL(linkClicked( const TQString& )),
-		this,TQT_SLOT(linkClickedInternal( const TQString& )));
+	connect(this,TQ_SIGNAL(linkClicked( const TQString& )),
+		this,TQ_SLOT(linkClickedInternal( const TQString& )));
 }
 
 void KexiContextHelp::linkClickedInternal(const TQString& link) {
