@@ -35,7 +35,7 @@ class TQTextEdit;
 
 class KexiBlobTableEdit : public KexiTableEdit
 {
-	Q_OBJECT
+	TQ_OBJECT
   
 	public:
 		KexiBlobTableEdit(KexiTableViewColumn &column, TQWidget *parent=0);
