@@ -34,7 +34,7 @@ class KFormulaPartView;
 
 class FormulaString : public TQDialog
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
