@@ -66,7 +66,7 @@ KivioCanvas::KivioCanvas( TQWidget *par, KivioView* view, KivioDoc* doc, TQScrol
   setBackgroundMode(NoBackground);
   setAcceptDrops(true);
   setMouseTracking(true);
-  setFocusPolicy(TQ_StrongFocus);
+  setFocusPolicy(TQWidget::StrongFocus);
   setFocus();
 
   m_showConnectorTargets = false;
@@ -79,8 +79,8 @@ KivioCanvas::KivioCanvas( TQWidget *par, KivioView* view, KivioDoc* doc, TQScrol
   m_pVertScrollBar->setPageStep(10);
   m_pHorzScrollBar->setPageStep(10);
 
-  connect(m_pVertScrollBar, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(scrollV(int)));
-  connect( m_pHorzScrollBar, TQT_SIGNAL(valueChanged(int)), TQT_SLOT(scrollH(int)));
+  connect(m_pVertScrollBar, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(scrollV(int)));
+  connect( m_pHorzScrollBar, TQ_SIGNAL(valueChanged(int)), TQ_SLOT(scrollH(int)));
 
   m_iXOffset = 0;
   m_iYOffset = 0;
@@ -100,7 +100,7 @@ KivioCanvas::KivioCanvas( TQWidget *par, KivioView* view, KivioDoc* doc, TQScrol
   unclippedPainter = 0L;
 
   m_borderTimer = new TQTimer(this);
-  connect(m_borderTimer,TQT_SIGNAL(timeout()),TQT_SLOT(borderTimerTimeout()));
+  connect(m_borderTimer,TQ_SIGNAL(timeout()),TQ_SLOT(borderTimerTimeout()));
 }
 
 KivioCanvas::~KivioCanvas()
@@ -331,7 +331,7 @@ void KivioCanvas::paintEvent( TQPaintEvent* ev )
 
   // Draw content
   KivioScreenPainter kpainter;
-  kpainter.start(TQT_TQPAINTDEVICE(m_buffer));
+  kpainter.start(m_buffer);
   kpainter.translateBy(-m_iXOffset + m_pageOffsetX, -m_iYOffset + m_pageOffsetY);
   m_pDoc->paintContent(kpainter, paintRect, false, page, TQPoint(0, 0), m_pView->zoomHandler(), showConnectorTargets(), true);
   kpainter.stop();
@@ -706,7 +706,7 @@ void KivioCanvas::beginUnclippedSpawnerPainter()
     unclippedSpawnerPainter = new KivioScreenPainter();
 
     // Tell it to start (allocates a Qpainter object)
-    unclippedSpawnerPainter->start(TQT_TQPAINTDEVICE(this));
+    unclippedSpawnerPainter->start(this);
 
     // Uhhhhh??
     if( !unclipped )
