@@ -33,7 +33,7 @@
 KPrObjectProperties::KPrObjectProperties( const TQPtrList<KPrObject> &objects )
 : m_objects( objects )
 , m_flags( 0 )
-, m_pen( KoPen( TQt::black, 1.0, Qt::SolidLine ), L_NORMAL, L_NORMAL )
+, m_pen( KoPen( TQt::black, 1.0, TQt::SolidLine ), L_NORMAL, L_NORMAL )
 , m_protectContent( STATE_UNDEF )
 {
     getProperties( m_objects );
