@@ -151,20 +151,20 @@ KPrSideBar::KPrSideBar(TQWidget *parent, KPrDocument *d, KPrView *v)
 
 
     //TODO find a better way
-    connect(m_outline, TQT_SIGNAL(showPage(int)),
-            this, TQT_SIGNAL(showPage(int)));
+    connect(m_outline, TQ_SIGNAL(showPage(int)),
+            this, TQ_SIGNAL(showPage(int)));
 
-    connect(m_thb, TQT_SIGNAL(showPage(int)),
-            this, TQT_SIGNAL(showPage(int)));
+    connect(m_thb, TQ_SIGNAL(showPage(int)),
+            this, TQ_SIGNAL(showPage(int)));
 
-    connect(m_outline, TQT_SIGNAL(movePage(int,int)),
-            this, TQT_SIGNAL(movePage(int,int)));
+    connect(m_outline, TQ_SIGNAL(movePage(int,int)),
+            this, TQ_SIGNAL(movePage(int,int)));
 
-    connect(m_outline, TQT_SIGNAL(selectPage(int,bool)),
-            this, TQT_SIGNAL(selectPage(int,bool)));
+    connect(m_outline, TQ_SIGNAL(selectPage(int,bool)),
+            this, TQ_SIGNAL(selectPage(int,bool)));
 
-    connect(this, TQT_SIGNAL(currentChanged(TQWidget *)),
-            this, TQT_SLOT(currentChanged(TQWidget *)));
+    connect(this, TQ_SIGNAL(currentChanged(TQWidget *)),
+            this, TQ_SLOT(currentChanged(TQWidget *)));
 
 }
 
@@ -247,10 +247,10 @@ KPrThumbBar::KPrThumbBar(TQWidget *parent, KPrDocument *d, KPrView *v)
 
     m_thumbTip = new ThumbToolTip(this);
 
-    connect(this, TQT_SIGNAL(currentChanged(TQIconViewItem *)),
-            this, TQT_SLOT(itemClicked(TQIconViewItem *)));
-    connect(this, TQT_SIGNAL(contentsMoving(int, int)),
-            this, TQT_SLOT(slotContentsMoving(int, int)));
+    connect(this, TQ_SIGNAL(currentChanged(TQIconViewItem *)),
+            this, TQ_SLOT(itemClicked(TQIconViewItem *)));
+    connect(this, TQ_SIGNAL(contentsMoving(int, int)),
+            this, TQ_SLOT(slotContentsMoving(int, int)));
 }
 
 KPrThumbBar::~KPrThumbBar()
@@ -347,7 +347,7 @@ void KPrThumbBar::rebuildItems()
             item->setDragEnabled(false);  //no dragging for now
         }
 
-        TQTimer::singleShot( 10, this, TQT_SLOT( slotRefreshItems() ) );
+        TQTimer::singleShot( 10, this, TQ_SLOT( slotRefreshItems() ) );
     }
     uptodate = true;
 
@@ -763,16 +763,16 @@ KPrOutline::KPrOutline( TQWidget *parent, KPrDocument *d, KPrView *v )
     addColumn( i18n( "Slide" ) );
     setSizePolicy( TQSizePolicy( TQSizePolicy::Minimum, TQSizePolicy::Expanding ) );
 
-    connect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
-    connect( this, TQT_SIGNAL( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ),
-             this, TQT_SLOT( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ) );
-    connect( this, TQT_SIGNAL( contextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ),
-             this, TQT_SLOT( slotContextMenu( TDEListView*, TQListViewItem*, const TQPoint&) ) );
+    connect( this, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( itemClicked( TQListViewItem * ) ) );
+    connect( this, TQ_SIGNAL( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ),
+             this, TQ_SLOT( rightButtonPressed( TQListViewItem *, const TQPoint &, int ) ) );
+    connect( this, TQ_SIGNAL( contextMenu( TDEListView*, TQListViewItem*, const TQPoint& ) ),
+             this, TQ_SLOT( slotContextMenu( TDEListView*, TQListViewItem*, const TQPoint&) ) );
 
-    connect( this, TQT_SIGNAL( doubleClicked ( TQListViewItem * )),
-             this, TQT_SLOT(renamePageTitle()));
-    connect( this, TQT_SIGNAL( dropped( TQDropEvent*, TQListViewItem*, TQListViewItem* ) ),
-             this, TQT_SLOT( slotDropped( TQDropEvent*, TQListViewItem*, TQListViewItem*  ) ));
+    connect( this, TQ_SIGNAL( doubleClicked ( TQListViewItem * )),
+             this, TQ_SLOT(renamePageTitle()));
+    connect( this, TQ_SIGNAL( dropped( TQDropEvent*, TQListViewItem*, TQListViewItem* ) ),
+             this, TQ_SLOT( slotDropped( TQDropEvent*, TQListViewItem*, TQListViewItem*  ) ));
 
     setItemsMovable( false );
     setDragEnabled( true );
@@ -998,9 +998,9 @@ void KPrOutline::setCurrentPage( int pg )
 
 void KPrOutline::contentsDropEvent( TQDropEvent *e )
 {
-    disconnect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
+    disconnect( this, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( itemClicked( TQListViewItem * ) ) );
     TDEListView::contentsDropEvent( e );
-    connect( this, TQT_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQT_SLOT( itemClicked( TQListViewItem * ) ) );
+    connect( this, TQ_SIGNAL( currentChanged( TQListViewItem * ) ), this, TQ_SLOT( itemClicked( TQListViewItem * ) ) );
 }
 
 void KPrOutline::moveItem( TQListViewItem *i, TQListViewItem *, TQListViewItem *newAfter )
