@@ -96,19 +96,19 @@ enum BorderShortcutType
 
 class PatternSelect : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     PatternSelect( TQWidget *parent, const char *_name );
 
-    void setPenStyle( Qt::PenStyle _pat ) { penStyle = _pat; repaint(); }
-    Qt::PenStyle getPenStyle() { return penStyle; }
+    void setPenStyle( TQt::PenStyle _pat ) { penStyle = _pat; repaint(); }
+    TQt::PenStyle getPenStyle() { return penStyle; }
     void setColor( const TQColor &_col ) { penColor = _col; repaint(); }
     const TQColor& getColor() { return penColor; }
     void setPenWidth( int _w ) { penWidth = _w; repaint(); }
     int getPenWidth() { return penWidth; }
 
-    void setPattern( const TQColor &_color, int _width, Qt::PenStyle _style );
+    void setPattern( const TQColor &_color, int _width, TQt::PenStyle _style );
     void setUndefined();
     void setDefined() { undefined = FALSE; repaint(); }
 
@@ -125,7 +125,7 @@ protected:
     virtual void paintEvent( TQPaintEvent *_ev );
     virtual void mousePressEvent( TQMouseEvent *_ev );
 
-    Qt::PenStyle penStyle;
+    TQt::PenStyle penStyle;
     TQColor penColor;
     int penWidth;
 
@@ -135,7 +135,7 @@ protected:
 
 class GeneralTab : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
@@ -164,7 +164,7 @@ class GeneralTab : public TQWidget
  */
 class CellFormatPageFont : public FontTab
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CellFormatPageFont( TQWidget* parent, CellFormatDialog *_dlg );
@@ -207,7 +207,7 @@ private:
  */
 class CellFormatPageFloat : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CellFormatPageFloat( TQWidget *parent, CellFormatDialog *_dlg );
@@ -251,7 +251,7 @@ protected:
 
 class CellFormatPagePosition : public PositionTab
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CellFormatPagePosition( TQWidget *parent, CellFormatDialog *_dlg );
@@ -283,7 +283,7 @@ protected:
 
 class Border : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     Border( TQWidget *parent,const char *_name,bool _oneCol,bool _oneRow  );
@@ -299,12 +299,12 @@ protected:
 
 class BorderButton : public TQPushButton
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     BorderButton( TQWidget *parent, const char *_name );
-    void setPenStyle( Qt::PenStyle _pat ) { penStyle = _pat;}
-    Qt::PenStyle getPenStyle() { return penStyle; }
+    void setPenStyle( TQt::PenStyle _pat ) { penStyle = _pat;}
+    TQt::PenStyle getPenStyle() { return penStyle; }
     void setColor( const TQColor &_col ) { penColor = _col; }
     const TQColor& getColor() { return penColor; }
     void setPenWidth( int _w ) { penWidth = _w; }
@@ -317,7 +317,7 @@ public:
     void clicked(BorderButton *);
  protected:
     virtual void mousePressEvent( TQMouseEvent *_ev );
-    Qt::PenStyle penStyle;
+    TQt::PenStyle penStyle;
     TQColor penColor;
     int penWidth;
     bool changed;
@@ -326,7 +326,7 @@ public:
 
 class CellFormatPageBorder : public TQWidget
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
     CellFormatPageBorder( TQWidget *parent, CellFormatDialog *_dlg );
@@ -384,16 +384,16 @@ private:
 
 class BrushSelect : public TQFrame
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     BrushSelect( TQWidget *parent, const char *_name );
 
-    void setBrushStyle( Qt::BrushStyle _pat ) { brushStyle = _pat; repaint(); }
-    Qt::BrushStyle getBrushStyle() const { return brushStyle; }
+    void setBrushStyle( TQt::BrushStyle _pat ) { brushStyle = _pat; repaint(); }
+    TQt::BrushStyle getBrushStyle() const { return brushStyle; }
     TQColor getBrushColor() const { return brushColor; }
     void setBrushColor(const TQColor &_c) { brushColor=_c;}
-    void setPattern( const TQColor &_color, Qt::BrushStyle _style );
+    void setPattern( const TQColor &_color, TQt::BrushStyle _style );
 
 signals:
     void clicked( BrushSelect *_this );
@@ -406,7 +406,7 @@ protected:
     virtual void paintEvent( TQPaintEvent *_ev );
     virtual void mousePressEvent( TQMouseEvent *_ev );
 
-    Qt::BrushStyle brushStyle;
+    TQt::BrushStyle brushStyle;
     TQColor brushColor;
     bool selected;
 };
@@ -414,7 +414,7 @@ protected:
 
 class CellFormatPagePattern : public TQWidget
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     CellFormatPagePattern( TQWidget *parent, CellFormatDialog *_dlg );
@@ -459,7 +459,7 @@ protected:
 
 class CellFormatPageProtection : public ProtectionTab
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 
  public:
@@ -482,7 +482,7 @@ class CellFormatPageProtection : public ProtectionTab
  */
 class CellFormatDialog : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /**
@@ -527,13 +527,13 @@ public:
       bool bStyle;
       TQColor color;
       bool bColor;
-      Qt::PenStyle style;
+      TQt::PenStyle style;
     };
 
     // The format of the selected area
     CellBorderFormat borders[BorderType_END];
 
-    Qt::BrushStyle brushStyle;
+    TQt::BrushStyle brushStyle;
     TQColor brushColor;
 
     bool oneCol;
