@@ -24,17 +24,17 @@
 
 #include "configdlg.h"
 #include "version.h"
-#include <klocale.h>
+#include <tdelocale.h>
 #include <knotifyclient.h>
 #include <tqlayout.h>
 #include <tqobjectlist.h>
 #include <tqpushbutton.h>
-#include <kapplication.h>
-#include <kglobalsettings.h>
+#include <tdeapplication.h>
+#include <tdeglobalsettings.h>
 #include <tqstyle.h>
 #include <kdialog.h>
-#include <kconfig.h>
-#include <kglobal.h>
+#include <tdeconfig.h>
+#include <tdeglobal.h>
 #include "kcalc.h"
 
 extern last_input_type last_input;
@@ -53,17 +53,17 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
     selection_timer = new TQTimer;
     status_timer = new TQTimer;
 
-    connect(status_timer,TQT_SIGNAL(timeout()),this,TQT_SLOT(clear_status_label()));
-    connect(selection_timer,TQT_SIGNAL(timeout()),this,TQT_SLOT(selection_timed_out()));
+    connect(status_timer,TQ_SIGNAL(timeout()),this,TQ_SLOT(clear_status_label()));
+    connect(selection_timer,TQ_SIGNAL(timeout()),this,TQ_SLOT(selection_timed_out()));
 
     readSettings();
 
-    TQFont buttonfont( KGlobalSettings::generalFont() );
+    TQFont buttonfont( TDEGlobalSettings::generalFont() );
     buttonfont.setStyleStrategy( TQFont::PreferAntialias );
 
     // Set the window caption/title
 
-    // connect(kapp,TQT_SIGNAL(kdisplayPaletteChanged()),this,TQT_SLOT(set_colors()));
+    // connect(kapp,TQ_SIGNAL(tdedisplayPaletteChanged()),this,TQ_SLOT(set_colors()));
     // setCaption( kapp->caption() );
 
     // create help button
@@ -75,30 +75,30 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
     pb->setFont( TQFont("times",12,TQFont::Bold,FALSE) );
     TQToolTip::add( pb, i18n("KCalc Setup/Help") );
 
-    connect( pb, TQT_SIGNAL(clicked()), TQT_SLOT(configclicked()) );
+    connect( pb, TQ_SIGNAL(clicked()), TQ_SLOT(configclicked()) );
 
     // Create the display
     calc_display = new DLabel( this, "display" );
     calc_display->setFrameStyle( TQFrame::WinPanel | TQFrame::Sunken );
     calc_display->setAlignment( AlignRight|AlignVCenter );
     calc_display->setFocus();
-    calc_display->setFocusPolicy( TQ_StrongFocus );
+    calc_display->setFocusPolicy( TQWidget::StrongFocus );
 
-    connect(calc_display,TQT_SIGNAL(clicked()),this,TQT_SLOT(display_selected()));
+    connect(calc_display,TQ_SIGNAL(clicked()),this,TQ_SLOT(display_selected()));
 
     statusINVLabel = new TQLabel( this, "INV" );
-    Q_CHECK_PTR( statusINVLabel );
+    TQ_CHECK_PTR( statusINVLabel );
     statusINVLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
     statusINVLabel->setAlignment( AlignCenter );
     statusINVLabel->setText("NORM");
 
     statusHYPLabel = new TQLabel( this, "HYP" );
-    Q_CHECK_PTR( statusHYPLabel );
+    TQ_CHECK_PTR( statusHYPLabel );
     statusHYPLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
     statusHYPLabel->setAlignment( AlignCenter );
 
     statusERRORLabel = new TQLabel( this, "ERROR" );
-    Q_CHECK_PTR( statusERRORLabel );
+    TQ_CHECK_PTR( statusERRORLabel );
     statusERRORLabel->setFrameStyle( TQFrame::Panel | TQFrame::Sunken );
     statusERRORLabel->setAlignment( AlignLeft|AlignVCenter );
 
@@ -106,26 +106,26 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
 
     TQAccel *accel = new TQAccel( this );
 
-    TQButtonGroup *angle_group = new TQButtonGroup( 3,Qt::Horizontal,this, "AngleButtons" );
+    TQButtonGroup *angle_group = new TQButtonGroup( 3,TQt::Horizontal,this, "AngleButtons" );
     angle_group->setTitle(i18n( "Angle") );
 
     anglebutton[0] = new TQRadioButton( angle_group );
     anglebutton[0]->setText( "&Deg" )   ;
     anglebutton[0]->setChecked(   TRUE);
     accel->connectItem( accel->insertItem(Key_D + ALT), this ,
-                        TQT_SLOT(Deg_Selected()) );
+                        TQ_SLOT(Deg_Selected()) );
 
     anglebutton[1] = new TQRadioButton( angle_group );
     anglebutton[1]->setText( "&Rad" );
     accel->connectItem( accel->insertItem(Key_R + ALT), this ,
-                        TQT_SLOT(Rad_Selected()) );
+                        TQ_SLOT(Rad_Selected()) );
 
     anglebutton[2] = new TQRadioButton( angle_group );
     anglebutton[2]->setText( "&Gra" );
     accel->connectItem( accel->insertItem(Key_G + ALT), this ,
-                        TQT_SLOT(Gra_Selected()) );
+                        TQ_SLOT(Gra_Selected()) );
 
-    connect( angle_group, TQT_SIGNAL(clicked(int)), TQT_SLOT(angle_selected(int)) );
+    connect( angle_group, TQ_SIGNAL(clicked(int)), TQ_SLOT(angle_selected(int)) );
 
 
 //////////////////////////////////////////////////////////////////////
@@ -135,31 +135,31 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
 
 
 
-    TQButtonGroup *base_group = new TQButtonGroup( 4,Qt::Horizontal,this, "BaseButtons" );
+    TQButtonGroup *base_group = new TQButtonGroup( 4,TQt::Horizontal,this, "BaseButtons" );
     base_group->setTitle( i18n("Base") );
 
     basebutton[0] = new TQRadioButton( base_group );
     basebutton[0]->setText( "&Hex" );
     accel->connectItem( accel->insertItem(Key_H + ALT), this ,
-                        TQT_SLOT(Hex_Selected()) );
+                        TQ_SLOT(Hex_Selected()) );
 
     basebutton[1] = new TQRadioButton( base_group );
     basebutton[1]->setText( "D&ec" );
     basebutton[1]->setChecked(TRUE);
     accel->connectItem( accel->insertItem(Key_E + ALT), this ,
-                        TQT_SLOT(Dec_Selected()) );
+                        TQ_SLOT(Dec_Selected()) );
 
     basebutton[2] = new TQRadioButton( base_group );
     basebutton[2]->setText( "&Oct" );
     accel->connectItem( accel->insertItem(Key_O + ALT), this ,
-                        TQT_SLOT(Oct_Selected()) );
+                        TQ_SLOT(Oct_Selected()) );
 
     basebutton[3] = new TQRadioButton( base_group);
     basebutton[3]->setText( "&Bin" );
     accel->connectItem( accel->insertItem(Key_B + ALT), this ,
-                        TQT_SLOT(Bin_Selected()) );
+                        TQ_SLOT(Bin_Selected()) );
 
-    connect( base_group, TQT_SIGNAL(clicked(int)), TQT_SLOT(base_selected(int)) );
+    connect( base_group, TQ_SIGNAL(clicked(int)), TQ_SLOT(base_selected(int)) );
 
 ////////////////////////////////////////////////////////////////////////
 //
@@ -172,203 +172,203 @@ TQtCalculator :: TQtCalculator( Calculator *_corba, TQWidget *parent, const char
     mLargePage = new TQWidget(this);
 
     pbhyp = new TQPushButton("Hyp", mSmallPage, "hypbutton" );
-    connect( pbhyp, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbhyptoggled(bool)));
+    connect( pbhyp, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbhyptoggled(bool)));
     pbhyp->setToggleButton(TRUE);
 
     pbinv = new TQPushButton( "Inv", mSmallPage, "InverseButton" );
-    connect( pbinv, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbinvtoggled(bool)));
+    connect( pbinv, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbinvtoggled(bool)));
     pbinv->setToggleButton(TRUE);
 
     pbA = new TQPushButton("A",mSmallPage, "Abutton" );
-    connect( pbA, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbAtoggled(bool)));
+    connect( pbA, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbAtoggled(bool)));
     pbA->setToggleButton(TRUE);
 
     pbSin = new TQPushButton("Sin",mSmallPage, "Sinbutton" );
-    connect( pbSin, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbSintoggled(bool)));
+    connect( pbSin, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbSintoggled(bool)));
     pbSin->setToggleButton(TRUE);
 
     pbplusminus = new TQPushButton( "+/-", mSmallPage, "plusminusbutton" );
-    connect( pbplusminus, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbplusminustoggled(bool)));
+    connect( pbplusminus, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbplusminustoggled(bool)));
     pbplusminus->setToggleButton(TRUE);
     pbplusminus->setFont(buttonfont);
 
     pbB = new TQPushButton("B", mSmallPage, "Bbutton" );
-    connect( pbB, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbBtoggled(bool)));
+    connect( pbB, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbBtoggled(bool)));
     pbB->setToggleButton(TRUE);
 
     pbCos = new TQPushButton("Cos",mSmallPage, "Cosbutton" );
     pbCos->setText( "Cos" );
-    connect( pbCos, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbCostoggled(bool)));
+    connect( pbCos, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbCostoggled(bool)));
     pbCos->setToggleButton(TRUE);
 
 
     pbreci = new TQPushButton("1/x",mSmallPage, "recibutton" );
-    connect( pbreci, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbrecitoggled(bool)));
+    connect( pbreci, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbrecitoggled(bool)));
     pbreci->setToggleButton(TRUE);
 
     pbC = new TQPushButton( "C", mSmallPage, "Cbutton" );
-    connect( pbC, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbCtoggled(bool)));
+    connect( pbC, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbCtoggled(bool)));
     pbC->setToggleButton(TRUE);
 
     pbTan = new TQPushButton("Tan" ,mSmallPage,  "Tanbutton" );
-    connect( pbTan, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbTantoggled(bool)));
+    connect( pbTan, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbTantoggled(bool)));
     pbTan->setToggleButton(TRUE);
 
     pbfactorial = new TQPushButton("x!",mSmallPage, "factorialbutton" );
-    connect( pbfactorial, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbfactorialtoggled(bool)));
+    connect( pbfactorial, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbfactorialtoggled(bool)));
     pbfactorial->setToggleButton(TRUE);
 
     pbD = new TQPushButton("D",mSmallPage,  "Dbutton" );
-    connect( pbD, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbDtoggled(bool)));
+    connect( pbD, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbDtoggled(bool)));
     pbD->setToggleButton(TRUE);
 
     pblog = new TQPushButton("Log",mSmallPage, "logbutton" );
-    connect( pblog, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pblogtoggled(bool)));
+    connect( pblog, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pblogtoggled(bool)));
     pblog->setToggleButton(TRUE);
 
     pbsquare = new TQPushButton( "x^2", mSmallPage,  "squarebutton" );
-    connect( pbsquare, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbsquaretoggled(bool)));
+    connect( pbsquare, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbsquaretoggled(bool)));
     pbsquare->setToggleButton(TRUE);
 
     pbE = new TQPushButton("E",mSmallPage, "Ebutton" );
-    connect( pbE, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbEtoggled(bool)));
+    connect( pbE, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbEtoggled(bool)));
     pbE->setToggleButton(TRUE);
 
 
     pbln = new TQPushButton( "Ln", mSmallPage, "lnbutton" );
-    connect( pbln, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pblntoggled(bool)));
+    connect( pbln, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pblntoggled(bool)));
     pbln->setToggleButton(TRUE);
 
     pbpower = new TQPushButton("x^y",mSmallPage,  "powerbutton" );
-    connect( pbpower, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbpowertoggled(bool)));
+    connect( pbpower, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbpowertoggled(bool)));
     pbpower->setToggleButton(TRUE);
 
     pbF = new TQPushButton("F",mSmallPage, "Fbutton" );
-    connect( pbF, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbFtoggled(bool)));
+    connect( pbF, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbFtoggled(bool)));
     pbF->setToggleButton(TRUE);
 
     pbEE = new TQPushButton("EE",mLargePage,  "EEbutton" );
     pbEE->setToggleButton(TRUE);
-    connect( pbEE, TQT_SIGNAL(toggled(bool)), TQT_SLOT(EEtoggled(bool)));
+    connect( pbEE, TQ_SIGNAL(toggled(bool)), TQ_SLOT(EEtoggled(bool)));
 
     pbMR = new TQPushButton("MR",mLargePage,  "MRbutton" );
-    connect( pbMR, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbMRtoggled(bool)));
+    connect( pbMR, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbMRtoggled(bool)));
     pbMR->setToggleButton(TRUE);
     pbMR->setFont(buttonfont);
 
     pbMplusminus = new TQPushButton("M+-",mLargePage,  "Mplusminusbutton" );
-    connect( pbMplusminus, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbMplusminustoggled(bool)));
+    connect( pbMplusminus, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbMplusminustoggled(bool)));
     pbMplusminus->setToggleButton(TRUE);
 
     pbMC = new TQPushButton("MC",mLargePage,  "MCbutton" );
-    connect( pbMC, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbMCtoggled(bool)));
+    connect( pbMC, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbMCtoggled(bool)));
     pbMC->setToggleButton(TRUE);
 
     pbClear = new TQPushButton("C",mLargePage,  "Clearbutton" );
-    connect( pbClear, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbCleartoggled(bool)));
+    connect( pbClear, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbCleartoggled(bool)));
     pbClear->setToggleButton(TRUE);
 
     pbAC = new TQPushButton("AC", mLargePage,  "ACbutton" );
-    connect( pbAC, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbACtoggled(bool)));
+    connect( pbAC, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbACtoggled(bool)));
     pbAC->setToggleButton(TRUE);
 
     pb7 = new TQPushButton("7",mLargePage, "7button" );
-    connect( pb7, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb7toggled(bool)));
+    connect( pb7, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb7toggled(bool)));
     pb7->setToggleButton(TRUE);
 
     pb8 = new TQPushButton("8",mLargePage, "8button" );
-    connect( pb8, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb8toggled(bool)));
+    connect( pb8, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb8toggled(bool)));
     pb8->setToggleButton(TRUE);
 
     pb9 = new TQPushButton("9",mLargePage,"9button" );
-    connect( pb9, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb9toggled(bool)));
+    connect( pb9, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb9toggled(bool)));
     pb9->setToggleButton(TRUE);
 
     pbparenopen = new TQPushButton("(",mLargePage,  "parenopenbutton" );
-    connect( pbparenopen, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbparenopentoggled(bool)));
+    connect( pbparenopen, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbparenopentoggled(bool)));
     pbparenopen->setToggleButton(TRUE);
 
     pbparenclose = new TQPushButton(")",mLargePage, "parenclosebutton" );
-    connect( pbparenclose, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbparenclosetoggled(bool)));
+    connect( pbparenclose, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbparenclosetoggled(bool)));
     pbparenclose->setToggleButton(TRUE);
 
     pband = new TQPushButton("And",mLargePage, "andbutton" );
-    connect( pband, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbandtoggled(bool)));
+    connect( pband, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbandtoggled(bool)));
     pband->setToggleButton(TRUE);
     pband->setFont(buttonfont);
 
     pb4 = new TQPushButton("4",mLargePage,  "4button" );
-    connect( pb4, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb4toggled(bool)));
+    connect( pb4, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb4toggled(bool)));
     pb4->setToggleButton(TRUE);
 
     pb5 = new TQPushButton("5",mLargePage,  "5button" );
-    connect( pb5, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb5toggled(bool)));
+    connect( pb5, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb5toggled(bool)));
     pb5->setToggleButton(TRUE);
 
     pb6 = new TQPushButton("6",mLargePage,  "6button" );
-    connect( pb6, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb6toggled(bool)));
+    connect( pb6, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb6toggled(bool)));
     pb6->setToggleButton(TRUE);
 
     pbX = new TQPushButton("X",mLargePage, "Multiplybutton" );
-    connect( pbX, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbXtoggled(bool)));
+    connect( pbX, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbXtoggled(bool)));
     pbX->setToggleButton(TRUE);
 
     pbdivision = new TQPushButton("/",mLargePage,  "divisionbutton" );
-    connect( pbdivision, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbdivisiontoggled(bool)));
+    connect( pbdivision, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbdivisiontoggled(bool)));
     pbdivision->setToggleButton(TRUE);
 
     pbor = new TQPushButton("Or",mLargePage,  "orbutton" );
-    connect( pbor, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbortoggled(bool)));
+    connect( pbor, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbortoggled(bool)));
     pbor->setToggleButton(TRUE);
 
     pb1 = new TQPushButton("1",mLargePage,  "1button" );
-    connect( pb1, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb1toggled(bool)));
+    connect( pb1, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb1toggled(bool)));
     pb1->setToggleButton(TRUE);
 
     pb2 = new TQPushButton("2",mLargePage,  "2button" );
 
-    connect( pb2, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb2toggled(bool)));
+    connect( pb2, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb2toggled(bool)));
     pb2->setToggleButton(TRUE);
 
     pb3 = new TQPushButton("3",mLargePage,  "3button" );
-    connect( pb3, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb3toggled(bool)));
+    connect( pb3, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb3toggled(bool)));
     pb3->setToggleButton(TRUE);
 
     pbplus = new TQPushButton("+",mLargePage, "plusbutton" );
-    connect( pbplus, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbplustoggled(bool)));
+    connect( pbplus, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbplustoggled(bool)));
     pbplus->setToggleButton(TRUE);
 
 
     pbminus = new TQPushButton("-",mLargePage,  "minusbutton" );
-    connect( pbminus, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbminustoggled(bool)));
+    connect( pbminus, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbminustoggled(bool)));
     pbminus->setToggleButton(TRUE);
 
     pbshift = new TQPushButton("Lsh",mLargePage, "shiftbutton" );
-    connect( pbshift, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbshifttoggled(bool)));
+    connect( pbshift, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbshifttoggled(bool)));
     pbshift->setToggleButton(TRUE);
 
     pbperiod = new TQPushButton(".",mLargePage,  "periodbutton" );
-    connect( pbperiod, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbperiodtoggled(bool)));
+    connect( pbperiod, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbperiodtoggled(bool)));
     pbperiod->setToggleButton(TRUE);
 
     pb0 = new TQPushButton("0",mLargePage,  "0button" );
-    connect( pb0, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pb0toggled(bool)));
+    connect( pb0, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pb0toggled(bool)));
     pb0->setToggleButton(TRUE);
 
     pbequal = new TQPushButton("=",mLargePage,  "equalbutton" );
-    connect( pbequal, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbequaltoggled(bool)));
+    connect( pbequal, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbequaltoggled(bool)));
     pbequal->setToggleButton(TRUE);
 
     pbpercent = new TQPushButton("%",mLargePage, "percentbutton" );
-    connect( pbpercent, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbpercenttoggled(bool)));
+    connect( pbpercent, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbpercenttoggled(bool)));
     pbpercent->setToggleButton(TRUE);
 
     pbnegate = new TQPushButton("Cmp",mLargePage,  "OneComplementbutton" );
-    connect( pbnegate, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbnegatetoggled(bool)));
+    connect( pbnegate, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbnegatetoggled(bool)));
     pbnegate->setToggleButton(TRUE);
 
     pbmod = new TQPushButton("Mod",mLargePage,  "modbutton" );
-    connect( pbmod, TQT_SIGNAL(toggled(bool)), TQT_SLOT(pbmodtoggled(bool)));
+    connect( pbmod, TQ_SIGNAL(toggled(bool)), TQ_SLOT(pbmodtoggled(bool)));
     pbmod->setToggleButton(TRUE);
 
     TQGridLayout *smallBtnLayout = new TQGridLayout(mSmallPage, 6, 3, 0,
@@ -1464,7 +1464,7 @@ void TQtCalculator::configclicked(){
   lay1->setMargin( KDialog::marginHint() );
   lay1->setSpacing( KDialog::spacingHint() );
 
-  TQGroupBox *box = new TQGroupBox(0,Qt::Vertical,about,"box");
+  TQGroupBox *box = new TQGroupBox(0,TQt::Vertical,about,"box");
   box->layout()->setSpacing(KDialog::spacingHint());
   box->layout()->setMargin(KDialog::marginHint());
   TQGridLayout *grid1 = new TQGridLayout(box->layout(),2,2);
@@ -1587,7 +1587,7 @@ void TQtCalculator::readSettings()
     TQColor tmpC(189, 255, 180);
     TQColor blackC(0,0,0);
 
-    KConfig *config = KGlobal::config();
+    TDEConfig *config = TDEGlobal::config();
 	config->setGroup("CalcPlugin");
     kcalcdefaults.forecolor = config->readColorEntry("ForeColor", &blackC);
 	kcalcdefaults.backcolor = config->readColorEntry("BackColor", &tmpC);
@@ -1606,7 +1606,7 @@ void TQtCalculator::readSettings()
 
 void TQtCalculator::writeSettings()
 {
-    KConfig *config = KGlobal::config();
+    TDEConfig *config = TDEGlobal::config();
 
 	config->setGroup("CalcPlugin");
 	config->writeEntry("ForeColor",kcalcdefaults.forecolor);
