@@ -87,7 +87,7 @@ Calculator::Calculator( View* parent, const char* name )
     parent->installEventFilter( this );
 
     (void)new TDEAction( i18n("Calculator"), SmallIcon("kcalc", CalcFactory::global()),
-                       0, this, TQT_SLOT( showCalculator() ), actionCollection(), "kspreadcalc");
+                       0, this, TQ_SLOT( showCalculator() ), actionCollection(), "kspreadcalc");
 }
 
 void Calculator::showCalculator()
