@@ -28,7 +28,7 @@ class Cell;
 
 class Inspector : public KDialogBase
 {
-Q_OBJECT
+TQ_OBJECT
   
 
 public:
