@@ -22,7 +22,7 @@ namespace Kugar
 
 class InputMask : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     InputMask( TQObject *parent = 0, const char *name = 0 );
