@@ -269,7 +269,7 @@ KoTextCursor * KWOasisPasteCommand::execute( KoTextCursor *c )
 
     TQBuffer buffer( m_data );
 
-    KoStore * store = KoStore::createStore( TQT_TQIODEVICE(&buffer), KoStore::Read );
+    KoStore * store = KoStore::createStore( &buffer, KoStore::Read );
     KWDocument* kwdoc = textdoc->textFrameSet()->kWordDocument();
     KWOasisLoader loader( kwdoc );
     loader.insertOasisData( store, c );
