@@ -32,9 +32,9 @@
 #include <KoParagDia_p.h> // for KoBorderPreview
 
 #include <knuminput.h>
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kiconloader.h>
-#include <kmessagebox.h>
+#include <tdemessagebox.h>
 #include <knumvalidator.h>
 #include <kcolorbutton.h>
 #include <kdebug.h>
@@ -332,8 +332,8 @@ void KWFrameDia::setupTab1(){ // TAB Frame Options
     if(m_frameType==FT_PICTURE)
     {
         m_cbAspectRatio = new TQCheckBox (i18n("Retain original aspect ratio"),m_tab1);
-        connect( m_cbAspectRatio, TQT_SIGNAL(toggled(bool)),
-                 this, TQT_SLOT(slotKeepRatioToggled(bool)));
+        connect( m_cbAspectRatio, TQ_SIGNAL(toggled(bool)),
+                 this, TQ_SLOT(slotKeepRatioToggled(bool)));
         bool show=true;
         bool on=true;
         if(m_frame) {
@@ -450,7 +450,7 @@ void KWFrameDia::setupTab1(){ // TAB Frame Options
         "This is what happens for the \"main text frameset\", but this option makes it possible "
         "to choose the same behavior for other framesets, for instance in magazine layouts."));
     if ( m_rResizeFrame )
-        connect( m_reconnect, TQT_SIGNAL( clicked() ), this, TQT_SLOT( setFrameBehaviorInputOn() ) );
+        connect( m_reconnect, TQ_SIGNAL( clicked() ), this, TQ_SLOT( setFrameBehaviorInputOn() ) );
     m_onpGrid->addRowSpacing( 0, KDialog::marginHint() + 5 );
     m_onpGrid->addWidget( m_reconnect, 1, 0 );
 
@@ -458,7 +458,7 @@ void KWFrameDia::setupTab1(){ // TAB Frame Options
     TQWhatsThis::add(m_noFollowup, i18n("<b>Do not create a followup frame:</b><br/>"
         "When a new page is created, no frame will be created for this frameset."));
     if ( m_rResizeFrame )
-        connect( m_noFollowup, TQT_SIGNAL( clicked() ), this, TQT_SLOT( setFrameBehaviorInputOn() ) );
+        connect( m_noFollowup, TQ_SIGNAL( clicked() ), this, TQ_SLOT( setFrameBehaviorInputOn() ) );
     m_onpGrid->addWidget( m_noFollowup, 2, 0 );
 
     m_copyRadio= new TQRadioButton (i18n ("Place a copy of this frame"), m_onNewPage);
@@ -469,7 +469,7 @@ void KWFrameDia::setupTab1(){ // TAB Frame Options
         "makes it possible to choose the same behavior for other framesets, for "
         "instance a company logo and/or title that should appear exactly the same on every page."));
     if ( m_rResizeFrame )
-        connect( m_copyRadio, TQT_SIGNAL( clicked() ), this, TQT_SLOT( setFrameBehaviorInputOff() ) );
+        connect( m_copyRadio, TQ_SIGNAL( clicked() ), this, TQ_SLOT( setFrameBehaviorInputOff() ) );
     m_onpGrid->addWidget( m_copyRadio, 3, 0);
 
     enableOnNewPageOptions();
@@ -556,7 +556,7 @@ void KWFrameDia::setupTab1(){ // TAB Frame Options
     m_cbProtectContent = new TQCheckBox( i18n("Protect content"), m_tab1);
     TQWhatsThis::add(m_cbProtectContent, i18n("<b>Protect content:</b><br/>"
         "Disallow changes to be made to the contents of the frame(s)."));
-    connect( m_cbProtectContent, TQT_SIGNAL(toggled ( bool ) ), this, TQT_SLOT(slotProtectContentChanged( bool )));
+    connect( m_cbProtectContent, TQ_SIGNAL(toggled ( bool ) ), this, TQ_SLOT(slotProtectContentChanged( bool )));
     row++;
     m_grid1->addMultiCellWidget(m_cbProtectContent,row,row, 0, 1);
     if( m_frameType != FT_TEXT || m_frame!=0 && m_frame->frameSet()==0) {
@@ -613,7 +613,7 @@ void KWFrameDia::setupTab2() { // TAB Text Runaround
 
     // First groupbox
     m_runGroup = new TQButtonGroup(  i18n( "Layout of Text in Other Frames" ), m_tab2);
-    m_runGroup->setColumnLayout( 0, Qt::Vertical );
+    m_runGroup->setColumnLayout( 0, TQt::Vertical );
     m_runGroup->layout()->setSpacing( KDialog::spacingHint() );
     TQGridLayout *groupBox1Layout = new TQGridLayout( m_runGroup->layout() );
     groupBox1Layout->setAlignment( TQt::AlignTop );
@@ -649,7 +649,7 @@ void KWFrameDia::setupTab2() { // TAB Text Runaround
 
     // Second groupbox
     m_runSideGroup = new TQButtonGroup(  i18n( "Run Around Side" ), m_tab2);
-    m_runSideGroup->setColumnLayout( 0, Qt::Vertical );
+    m_runSideGroup->setColumnLayout( 0, TQt::Vertical );
     m_runSideGroup->layout()->setSpacing( KDialog::spacingHint() );
     m_runSideGroup->layout()->setMargin( KDialog::marginHint() );
     TQGridLayout *runSideLayout = new TQGridLayout( m_runSideGroup->layout() );
@@ -778,7 +778,7 @@ void KWFrameDia::setupTab2() { // TAB Text Runaround
     enableRunAround();
 
     // Changing the type of runaround needs to enable/disable the runaround-side options
-    connect( m_runGroup, TQT_SIGNAL( clicked(int) ), this, TQT_SLOT( enableRunAround() ) );
+    connect( m_runGroup, TQ_SIGNAL( clicked(int) ), this, TQ_SLOT( enableRunAround() ) );
 }
 
 void KWFrameDia::setupTab3(){ // TAB Frameset
@@ -801,7 +801,7 @@ void KWFrameDia::setupTab3(){ // TAB Frameset
     m_rExistingFrameset->setText( i18n("Select existing frameset to connect frame to:") );
     tabLayout->addWidget( m_rExistingFrameset );
     myGroup->insert(m_rExistingFrameset,1);
-    connect (m_rExistingFrameset, TQT_SIGNAL( toggled(bool)), this, TQT_SLOT(ensureValidFramesetSelected()));
+    connect (m_rExistingFrameset, TQ_SIGNAL( toggled(bool)), this, TQ_SLOT(ensureValidFramesetSelected()));
 
     TQHBoxLayout *layout2 = new TQHBoxLayout( 0, 0, 6);
     TQSpacerItem* spacer = new TQSpacerItem( 20, 20, TQSizePolicy::Minimum, TQSizePolicy::Expanding );
@@ -812,8 +812,8 @@ void KWFrameDia::setupTab3(){ // TAB Frameset
     m_lFrameSList->addColumn( i18n("Frameset Name") );
     m_lFrameSList->setAllColumnsShowFocus( true );
     m_lFrameSList->header()->setMovingEnabled( false );
-    connect( m_lFrameSList, TQT_SIGNAL(selectionChanged ()),this,TQT_SLOT(selectExistingFrameset ()) );
-    connect (m_lFrameSList, TQT_SIGNAL( selectionChanged()), this, TQT_SLOT(ensureValidFramesetSelected()));
+    connect( m_lFrameSList, TQ_SIGNAL(selectionChanged ()),this,TQ_SLOT(selectExistingFrameset ()) );
+    connect (m_lFrameSList, TQ_SIGNAL( selectionChanged()), this, TQ_SLOT(ensureValidFramesetSelected()));
 
     layout2->addWidget( m_lFrameSList );
     tabLayout->addLayout( layout2 );
@@ -881,14 +881,14 @@ void KWFrameDia::setupTab3(){ // TAB Frameset
     }
     m_eFrameSetName->setText( m_oldFrameSetName );
 
-    connect( m_lFrameSList, TQT_SIGNAL( currentChanged( TQListViewItem * ) ),
-             this, TQT_SLOT( connectListSelected( TQListViewItem * ) ) );
-    connect(m_eFrameSetName, TQT_SIGNAL(textChanged ( const TQString & ) ),
-             this,TQT_SLOT(textNameFrameChanged ( const TQString & ) ) );
-    connect(m_eFrameSetName, TQT_SIGNAL(textChanged ( const TQString & )),
-             this,TQT_SLOT(textNameFrameChanged ( const TQString & ) ));
-    connect( m_rNewFrameset, TQT_SIGNAL(toggled (bool)),
-             this,TQT_SLOT(selectNewFrameset (bool)) );
+    connect( m_lFrameSList, TQ_SIGNAL( currentChanged( TQListViewItem * ) ),
+             this, TQ_SLOT( connectListSelected( TQListViewItem * ) ) );
+    connect(m_eFrameSetName, TQ_SIGNAL(textChanged ( const TQString & ) ),
+             this,TQ_SLOT(textNameFrameChanged ( const TQString & ) ) );
+    connect(m_eFrameSetName, TQ_SIGNAL(textChanged ( const TQString & )),
+             this,TQ_SLOT(textNameFrameChanged ( const TQString & ) ));
+    connect( m_rNewFrameset, TQ_SIGNAL(toggled (bool)),
+             this,TQ_SLOT(selectNewFrameset (bool)) );
 }
 
 void KWFrameDia::selectExistingFrameset() {
@@ -929,14 +929,14 @@ void KWFrameDia::setupTab4() { // TAB Geometry
 
     m_floating = new TQCheckBox( i18n("Frame is inline"), m_tab4 );
 
-    connect( m_floating, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( slotFloatingToggled(bool) ) );
+    connect( m_floating, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( slotFloatingToggled(bool) ) );
     int row = 0;
     grid4->addMultiCellWidget( m_floating, row, row, 0, 1 );
 
     row++;
     m_protectSize = new TQCheckBox( i18n("Protect size and position"), m_tab4);
     grid4->addMultiCellWidget( m_protectSize, row, row, 0, 1 );
-    connect( m_protectSize, TQT_SIGNAL( toggled(bool) ), this, TQT_SLOT( slotProtectSizeToggled(bool) ) );
+    connect( m_protectSize, TQ_SIGNAL( toggled(bool) ), this, TQ_SLOT( slotProtectSizeToggled(bool) ) );
 
     /* ideally the following properties could be given to any floating frame:
        Position: (y)
@@ -984,8 +984,8 @@ void KWFrameDia::setupTab4() { // TAB Geometry
     m_sw = new KoUnitDoubleSpinBox( m_grp1, 0, 9999, 1, 0.0, m_doc->unit() );
 
     m_sw->resize( m_sw->sizeHint() );
-    connect( m_sw, TQT_SIGNAL(valueChanged(double)),
-             this, TQT_SLOT(slotUpdateHeightForWidth(double)) );
+    connect( m_sw, TQ_SIGNAL(valueChanged(double)),
+             this, TQ_SLOT(slotUpdateHeightForWidth(double)) );
 
     pGrid->addWidget( m_sw, 2, 1 );
 
@@ -994,8 +994,8 @@ void KWFrameDia::setupTab4() { // TAB Geometry
     pGrid->addWidget( m_lh, 2, 2 );
 
     m_sh = new KoUnitDoubleSpinBox( m_grp1, 0, 9999, 1, 0.0, m_doc->unit() );
-    connect( m_sh, TQT_SIGNAL(valueChanged(double)),
-             this, TQT_SLOT(slotUpdateWidthForHeight(double)) );
+    connect( m_sh, TQ_SIGNAL(valueChanged(double)),
+             this, TQ_SLOT(slotUpdateWidthForHeight(double)) );
 
     m_sh->resize( m_sh->sizeHint() );
 
@@ -1176,8 +1176,8 @@ void KWFrameDia::setupTab5() { // Tab Background fill/color
     m_brushColor = new KColorButton( TQt::white, KWDocument::defaultBgColor(0), m_tab5 );
     grid5->addWidget(m_brushColor,row++,0);
 
-//    connect( m_brushColor, TQT_SIGNAL( changed( const TQColor & ) ),
-//        this, TQT_SLOT( updateBrushPreview() ) );
+//    connect( m_brushColor, TQ_SIGNAL( changed( const TQColor & ) ),
+//        this, TQ_SLOT( updateBrushPreview() ) );
 
 
     // ###########################
@@ -1213,14 +1213,14 @@ void KWFrameDia::setupTab5() { // Tab Background fill/color
     brushStyle->insertItem( i18n( "Diagonal Lines ( / )" ) );
     brushStyle->insertItem( i18n( "Diagonal Lines ( \\ )" ) );
     brushStyle->insertItem( i18n( "Diagonal Crossing Lines" ) );
-    connect(  brushStyle, TQT_SIGNAL( activated( int ) ),
-        this, TQT_SLOT( updateBrushPreview() ) );
+    connect(  brushStyle, TQ_SIGNAL( activated( int ) ),
+        this, TQ_SLOT( updateBrushPreview() ) );
 
     updateBrushPreview();
 #endif
 
-    connect( m_transparentCB, TQT_SIGNAL( toggled( bool ) ), labelBgColor, TQT_SLOT( setDisabled( bool ) ) );
-    connect( m_transparentCB, TQT_SIGNAL( toggled( bool ) ), m_brushColor, TQT_SLOT( setDisabled( bool ) ) );
+    connect( m_transparentCB, TQ_SIGNAL( toggled( bool ) ), labelBgColor, TQ_SLOT( setDisabled( bool ) ) );
+    connect( m_transparentCB, TQ_SIGNAL( toggled( bool ) ), m_brushColor, TQ_SLOT( setDisabled( bool ) ) );
     initBrush();
 
     TQSpacerItem* spacer = new TQSpacerItem( 10, 10, TQSizePolicy::Minimum, TQSizePolicy::Expanding);
@@ -1281,14 +1281,14 @@ void KWFrameDia::setupTab6() // Border style
     m_bBottom->setToggleButton( true );
     grid->addWidget( bb, 6, 0 );
 
-    connect( m_bLeft, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( brdLeftToggled( bool ) ) );
-    connect( m_bRight, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( brdRightToggled( bool ) ) );
-    connect( m_bTop, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( brdTopToggled( bool ) ) );
-    connect( m_bBottom, TQT_SIGNAL( toggled( bool ) ), this, TQT_SLOT( brdBottomToggled( bool ) ) );
+    connect( m_bLeft, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( brdLeftToggled( bool ) ) );
+    connect( m_bRight, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( brdRightToggled( bool ) ) );
+    connect( m_bTop, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( brdTopToggled( bool ) ) );
+    connect( m_bBottom, TQ_SIGNAL( toggled( bool ) ), this, TQ_SLOT( brdBottomToggled( bool ) ) );
 
     initBorderSettings();
 
-    TQGroupBox *grp=new TQGroupBox( 0, Qt::Vertical, i18n( "Preview" ), m_tab6, "previewgrp" );
+    TQGroupBox *grp=new TQGroupBox( 0, TQt::Vertical, i18n( "Preview" ), m_tab6, "previewgrp" );
     grid->addMultiCellWidget( grp , 0, 7, 1, 1 );
     grp->layout()->setSpacing(KDialog::spacingHint());
     grp->layout()->setMargin(KDialog::marginHint());
@@ -1296,8 +1296,8 @@ void KWFrameDia::setupTab6() // Border style
     TQVBoxLayout *lay1 = new TQVBoxLayout( grp->layout() );
     lay1->addWidget(m_prev3);
 
-    connect( m_prev3, TQT_SIGNAL( choosearea(TQMouseEvent * ) ),
-             this, TQT_SLOT( slotPressEvent(TQMouseEvent *) ) );
+    connect( m_prev3, TQ_SIGNAL( choosearea(TQMouseEvent * ) ),
+             this, TQ_SLOT( slotPressEvent(TQMouseEvent *) ) );
 
     // update the bordet preview widget
     m_prev3->setLeftBorder( m_leftBorder );
@@ -1561,7 +1561,7 @@ TQBrush KWFrameDia::frameBrushStyle() const
 {
     TQBrush brush;
 
-    brush.setStyle( m_transparentCB->isChecked() ? Qt::NoBrush : Qt::SolidPattern );
+    brush.setStyle( m_transparentCB->isChecked() ? TQt::NoBrush : TQt::SolidPattern );
 
 #if 0
     switch ( brushStyle->currentItem() )
@@ -2433,10 +2433,10 @@ KWFourSideConfigWidget::KWFourSideConfigWidget( KWDocument* doc, const TQString&
     mGrid->addWidget( m_inputBottom, 3, 3 );
     mGrid->setRowSpacing( 0, KDialog::spacingHint() + 5 );
 
-    connect( m_inputLeft, TQT_SIGNAL( valueChanged(double)), this, TQT_SLOT( slotValueChanged( double )));
-    connect( m_inputRight, TQT_SIGNAL( valueChanged(double)), this, TQT_SLOT( slotValueChanged( double )));
-    connect( m_inputTop, TQT_SIGNAL( valueChanged(double)), this, TQT_SLOT( slotValueChanged( double )));
-    connect( m_inputBottom, TQT_SIGNAL( valueChanged(double)), this, TQT_SLOT( slotValueChanged( double )));
+    connect( m_inputLeft, TQ_SIGNAL( valueChanged(double)), this, TQ_SLOT( slotValueChanged( double )));
+    connect( m_inputRight, TQ_SIGNAL( valueChanged(double)), this, TQ_SLOT( slotValueChanged( double )));
+    connect( m_inputTop, TQ_SIGNAL( valueChanged(double)), this, TQ_SLOT( slotValueChanged( double )));
+    connect( m_inputBottom, TQ_SIGNAL( valueChanged(double)), this, TQ_SLOT( slotValueChanged( double )));
 }
 
 // Called right after the ctor, so m_synchronize can't be checked
