@@ -52,8 +52,8 @@ KWFrameSet::KWFrameSet( KWDocument *doc )
     // Send our "repaintChanged" signals to the document.
     setName("KWFrameSet");
     if(m_doc) {
-        connect( this, TQT_SIGNAL( repaintChanged( KWFrameSet * ) ),
-             doc, TQT_SLOT( slotRepaintChanged( KWFrameSet * ) ) );
+        connect( this, TQ_SIGNAL( repaintChanged( KWFrameSet * ) ),
+             doc, TQ_SLOT( slotRepaintChanged( KWFrameSet * ) ) );
         m_pageManager = doc->pageManager();
     }
     m_frames.setAutoDelete( true );
@@ -260,7 +260,7 @@ void KWFrameSet::drawFrameBorder( TQPainter *painter, KWFrame *frame, KWFrame *s
     // ...except when printing, or embedded doc, or disabled.
     if ( !viewMode || !viewMode->drawFrameBorders() )
     {
-        viewSetting = TQPen(Qt::NoPen);
+        viewSetting = TQPen(TQt::NoPen);
         minBorder = 0;
     }
 
@@ -960,7 +960,7 @@ KWFrame* KWFrameSet::loadOasisFrame( const TQDomElement& tag, KoOasisContext& co
     frame->setZOrder( tag.attributeNS( KoXmlNS::draw, "z-index", TQString() ).toInt() );
     // Copy-frames.
     // We currently ignore the value of the copy-of attribute. It probably needs to
-    // be handled like chain-next-name (kwtextframeset.cc) but for all types of frameset.
+    // be handled like chain-next-name (kwtextframeset.cpp) but for all types of frameset.
     frame->setCopy( tag.hasAttributeNS( KoXmlNS::draw, "copy-of" ) );
     frame->loadCommonOasisProperties( context, this, "graphic" );
 
