@@ -60,7 +60,7 @@ class TQProgressDialog;
  */
 class KWFrameSet : public TQObject
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /// constructor
