@@ -34,7 +34,7 @@ class KoTextDocCommand;
  */
 class KWTextDocument : public KoTextDocument
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 public:
     /** A real text document inside a frameset */
