@@ -32,7 +32,7 @@
 #include <KoXmlNS.h>
 #include <KoDom.h>
 
-#include <klocale.h>
+#include <tdelocale.h>
 #include <kdebug.h>
 
 KWVariableSettings::KWVariableSettings() : KoVariableSettings()
