@@ -56,7 +56,7 @@ namespace KParts
  */
 class KOFFICECORE_EXPORT KoView : public TQWidget, public KParts::PartBase
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   /**
@@ -472,7 +472,7 @@ private:
  */
 class KoViewChild : public KoChild
 {
-  Q_OBJECT
+  TQ_OBJECT
   
 public:
   KoViewChild( KoDocumentChild *child, KoView *_parentView );
