@@ -46,7 +46,7 @@ enum { FORMAT_AND_BORDERS = 1, HEADER_AND_FOOTER = 2, COLUMNS = 4, DISABLE_BORDE
  */
 class KoPagePreview : public TQGroupBox
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
@@ -82,7 +82,7 @@ class KoPageLayoutDiaPrivate;
  */
 class KOFFICEUI_EXPORT KoPageLayoutDia : public KDialogBase
 {
-    Q_OBJECT
+    TQ_OBJECT
   
 
 public:
