@@ -71,12 +71,12 @@ void KoVariableNameDia::init()
     names = new TQComboBox( TRUE, row1 );
     names->setFocus();
 
-    connect( names, TQT_SIGNAL( textChanged ( const TQString & )),
-             this, TQT_SLOT( textChanged ( const TQString & )));
-    connect( this, TQT_SIGNAL( okClicked() ),
-             this, TQT_SLOT( accept() ) );
-    connect( this, TQT_SIGNAL( cancelClicked() ),
-             this, TQT_SLOT( reject() ) );
+    connect( names, TQ_SIGNAL( textChanged ( const TQString & )),
+             this, TQ_SLOT( textChanged ( const TQString & )));
+    connect( this, TQ_SIGNAL( okClicked() ),
+             this, TQ_SLOT( accept() ) );
+    connect( this, TQ_SIGNAL( cancelClicked() ),
+             this, TQ_SLOT( reject() ) );
     enableButtonOK( !names->currentText().isEmpty() );
     resize( 350, 100 );
 }
@@ -164,10 +164,10 @@ KoCustomVariablesList::KoCustomVariablesList( TQWidget *parent )
     header()->setMovingEnabled( FALSE );
     addColumn( i18n( "Variable" ) );
     addColumn( i18n( "Value" ) );
-    connect( header(), TQT_SIGNAL( sizeChange( int, int, int ) ),
-             this, TQT_SLOT( columnSizeChange( int, int, int ) ) );
-    connect( header(), TQT_SIGNAL( sectionClicked( int ) ),
-             this, TQT_SLOT( sectionClicked( int ) ) );
+    connect( header(), TQ_SIGNAL( sizeChange( int, int, int ) ),
+             this, TQ_SLOT( columnSizeChange( int, int, int ) ) );
+    connect( header(), TQ_SIGNAL( sectionClicked( int ) ),
+             this, TQ_SLOT( sectionClicked( int ) ) );
 
     setResizeMode(TQListView::LastColumn);
     setSorting( -1 );
@@ -227,10 +227,10 @@ KoCustomVariablesDia::KoCustomVariablesDia( TQWidget *parent, const TQPtrList<Ko
     }
 
 
-    connect( this, TQT_SIGNAL( okClicked() ),
-             this, TQT_SLOT( slotOk() ) );
-    connect( this, TQT_SIGNAL( cancelClicked() ),
-             this, TQT_SLOT( reject() ) );
+    connect( this, TQ_SIGNAL( okClicked() ),
+             this, TQ_SLOT( slotOk() ) );
+    connect( this, TQ_SIGNAL( cancelClicked() ),
+             this, TQ_SLOT( reject() ) );
     showButtonOK(lst.count()>0);
 
     resize( 600, 400 );
@@ -255,13 +255,13 @@ KoCustomVarDialog::KoCustomVarDialog( TQWidget *parent )
     m_name->setFocus();
 
 
-    connect( this, TQT_SIGNAL( okClicked() ),
-             this, TQT_SLOT( slotAddOk() ) );
-    connect( this, TQT_SIGNAL( cancelClicked() ),
-             this, TQT_SLOT( reject() ) );
+    connect( this, TQ_SIGNAL( okClicked() ),
+             this, TQ_SLOT( slotAddOk() ) );
+    connect( this, TQ_SIGNAL( cancelClicked() ),
+             this, TQ_SLOT( reject() ) );
 
-    connect( m_name, TQT_SIGNAL( textChanged(const TQString&) ),
-             this, TQT_SLOT( slotTextChanged(const TQString&) ) );
+    connect( m_name, TQ_SIGNAL( textChanged(const TQString&) ),
+             this, TQ_SLOT( slotTextChanged(const TQString&) ) );
 
     enableButtonOK( false );
     resize( 350, 100 );
@@ -279,13 +279,13 @@ KoCustomVarDialog::KoCustomVarDialog( TQWidget *parent, KoCustomVariable *var )
     m_value->setFocus();
 
 
-    connect( this, TQT_SIGNAL( okClicked() ),
-             this, TQT_SLOT( slotEditOk() ) );
-    connect( this, TQT_SIGNAL( cancelClicked() ),
-             this, TQT_SLOT( reject() ) );
+    connect( this, TQ_SIGNAL( okClicked() ),
+             this, TQ_SLOT( slotEditOk() ) );
+    connect( this, TQ_SIGNAL( cancelClicked() ),
+             this, TQ_SLOT( reject() ) );
 
-    connect( m_value, TQT_SIGNAL( textChanged(const TQString&) ),
-             this, TQT_SLOT( slotTextChanged(const TQString&) ) );
+    connect( m_value, TQ_SIGNAL( textChanged(const TQString&) ),
+             this, TQ_SLOT( slotTextChanged(const TQString&) ) );
 
     enableButtonOK( true );
     resize( 350, 100 );
