@@ -118,7 +118,7 @@ TQPair<int, int> KoTextFormatterCore::determineCharWidth()
     }
     Q_ASSERT( ww >= 0 );
     c->width = ww;
-    return tqMakePair(ww, pixelww);
+    return qMakePair(ww, pixelww);
 }
 
 
@@ -257,7 +257,7 @@ bool KoTextFormatterCore::format()
 
     int col = 0;
 
-    maxAvailableWidth = tqMakePair( 0, 0 );
+    maxAvailableWidth = qMakePair( 0, 0 );
 
     KoTextZoomHandler *zh = doc->formattingZoomHandler();
     int pixelx = zh->layoutUnitToPixelX( x );
