@@ -68,12 +68,12 @@ KoTextView::KoTextView( KoTextObject *textobj )
     m_bReadWrite = true;
     m_textobj = textobj;
     dcop=0;
-    connect( m_textobj, TQT_SIGNAL( hideCursor() ), this, TQT_SLOT( hideCursor() ) );
-    connect( m_textobj, TQT_SIGNAL( showCursor() ), this, TQT_SLOT( showCursor() ) );
-    connect( m_textobj, TQT_SIGNAL( setCursor( KoTextCursor * ) ), this, TQT_SLOT( setCursor( KoTextCursor * ) ) );
-    connect( m_textobj, TQT_SIGNAL( updateUI(bool, bool) ), this, TQT_SLOT( updateUI(bool, bool) ) );
-    connect( m_textobj, TQT_SIGNAL( showCurrentFormat() ), this, TQT_SLOT( showCurrentFormat() ) );
-    connect( m_textobj, TQT_SIGNAL( ensureCursorVisible() ), this, TQT_SLOT( ensureCursorVisible() ) );
+    connect( m_textobj, TQ_SIGNAL( hideCursor() ), this, TQ_SLOT( hideCursor() ) );
+    connect( m_textobj, TQ_SIGNAL( showCursor() ), this, TQ_SLOT( showCursor() ) );
+    connect( m_textobj, TQ_SIGNAL( setCursor( KoTextCursor * ) ), this, TQ_SLOT( setCursor( KoTextCursor * ) ) );
+    connect( m_textobj, TQ_SIGNAL( updateUI(bool, bool) ), this, TQ_SLOT( updateUI(bool, bool) ) );
+    connect( m_textobj, TQ_SIGNAL( showCurrentFormat() ), this, TQ_SLOT( showCurrentFormat() ) );
+    connect( m_textobj, TQ_SIGNAL( ensureCursorVisible() ), this, TQ_SLOT( ensureCursorVisible() ) );
 
     m_cursor = new KoTextCursor( m_textobj->textDocument() );
 
@@ -81,14 +81,14 @@ KoTextView::KoTextView( KoTextObject *textobj )
 
     showCursor();
     blinkTimer = new TQTimer( this );
-    connect( blinkTimer, TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( blinkCursor() ) );
+    connect( blinkTimer, TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( blinkCursor() ) );
     if ( TQApplication::cursorFlashTime() > 0 )
         blinkTimer->start( TQApplication::cursorFlashTime() / 2 );
 
     dragStartTimer = new TQTimer( this );
-    connect( dragStartTimer, TQT_SIGNAL( timeout() ),
-             this, TQT_SLOT( startDrag() ) );
+    connect( dragStartTimer, TQ_SIGNAL( timeout() ),
+             this, TQ_SLOT( startDrag() ) );
 
     m_textobj->formatMore( 2 );
 
@@ -702,7 +702,7 @@ bool KoTextView::handleMousePressEvent( TQMouseEvent *e, const TQPoint &iPoint,
     addParag = placeCursor( iPoint, insertDirectCursor&& isReadWrite() );
     ensureCursorVisible();
 
-    if ( e->button() != Qt::LeftButton )
+    if ( e->button() != TQt::LeftButton )
     {
         showCursor();
         return addParag;
@@ -837,7 +837,7 @@ void KoTextView::handleMouseDoubleClickEvent( TQMouseEvent*ev, const TQPoint& i
 
     possibleTripleClick=true;
 
-    TQTimer::singleShot(TQApplication::doubleClickInterval(),this,TQT_SLOT(tripleClickTimeout()));
+    TQTimer::singleShot(TQApplication::doubleClickInterval(),this,TQ_SLOT(tripleClickTimeout()));
 }
 
 void KoTextView::tripleClickTimeout()
@@ -847,7 +847,7 @@ void KoTextView::tripleClickTimeout()
 
 void KoTextView::handleMouseTripleClickEvent( TQMouseEvent*ev, const TQPoint& /* Currently unused */ )
 {
-    if ( ev->button() != Qt::LeftButton)
+    if ( ev->button() != TQt::LeftButton)
     {
         showCursor();
         return;
@@ -855,7 +855,7 @@ void KoTextView::handleMouseTripleClickEvent( TQMouseEvent*ev, const TQPoint& /*
     afterTripleClick= true;
     inDoubleClick = FALSE;
     *m_cursor = selectParagUnderCursor( *m_cursor );
-    TQTimer::singleShot(TQApplication::doubleClickInterval(),this,TQT_SLOT(afterTripleClickTimeout()));
+    TQTimer::singleShot(TQApplication::doubleClickInterval(),this,TQ_SLOT(afterTripleClickTimeout()));
 }
 
 void KoTextView::afterTripleClickTimeout()
@@ -1133,7 +1133,7 @@ TQPtrList<TDEAction> KoTextView::dataToolActionList(TDEInstance * instance, cons
     // Maybe one day we'll have tools that use libkotext (or qt3's qrt), to act on formatted text
     tools += KDataToolInfo::query( "KoTextString", "application/x-qrichtext", instance );
 
-    return KDataToolAction::dataToolActionList( tools, this, TQT_SLOT( slotToolActivated( const KDataToolInfo &, const TQString & ) ) );
+    return KDataToolAction::dataToolActionList( tools, this, TQ_SLOT( slotToolActivated( const KDataToolInfo &, const TQString & ) ) );
 }
 
 TQString KoTextView::currentWordOrSelection() const
