@@ -44,7 +44,7 @@ namespace Kross { namespace Api {
         : public TQObject
         , public KXMLGUIClient
     {
-            Q_OBJECT
+            TQ_OBJECT
   
             //TQ_PROPERTY(TQString configfile READ getConfigFile WRITE setConfigFile)
 
