@@ -91,8 +91,8 @@ Thesaurus::Thesaurus(TQObject* parent, const char* name, const TQStringList &)
     m_edit = new KHistoryCombo(m_page);
     m_edit_label = new TQLabel(m_edit, i18n("&Search for:"), m_page);
     m_search = new KPushButton(i18n("S&earch"), m_page);
-    connect(m_search, TQT_SIGNAL(clicked()),
-        this, TQT_SLOT(slotFindTerm()));
+    connect(m_search, TQ_SIGNAL(clicked()),
+        this, TQ_SLOT(slotFindTerm()));
     row1->addWidget(m_edit_label, 0);
     row1->addWidget(m_edit, 1);
     row1->addWidget(m_search, 0);
@@ -105,11 +105,11 @@ Thesaurus::Thesaurus(TQObject* parent, const char* name, const TQStringList &)
     TQToolTip::add(m_forward, i18n("Forward"));
     row1->addWidget(m_forward, 0);
     m_lang = new KPushButton(i18n("Change Language..."), m_page);
-    connect(m_lang, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotChangeLanguage()));
+    connect(m_lang, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotChangeLanguage()));
     row1->addWidget(m_lang, 0);
 
-    connect(m_back, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotBack()));
-    connect(m_forward, TQT_SIGNAL(clicked()), this, TQT_SLOT(slotForward()));
+    connect(m_back, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotBack()));
+    connect(m_forward, TQ_SIGNAL(clicked()), this, TQ_SLOT(slotForward()));
     
     m_tab = new TQTabWidget(m_page);
     m_top_layout->addWidget(m_tab);
@@ -126,39 +126,39 @@ Thesaurus::Thesaurus(TQObject* parent, const char* name, const TQStringList &)
     TQHBox *hbox = new TQHBox(vbox);
     hbox->setSpacing(KDialog::spacingHint());
 
-    grpbox_syn = new TQGroupBox( 1, Qt::Horizontal, i18n("Synonyms"), hbox);
+    grpbox_syn = new TQGroupBox( 1, TQt::Horizontal, i18n("Synonyms"), hbox);
     m_thes_syn = new TQListBox(grpbox_syn);
     
-    grpbox_hyper = new TQGroupBox( 1, Qt::Horizontal, i18n("More General Words"), hbox);
+    grpbox_hyper = new TQGroupBox( 1, TQt::Horizontal, i18n("More General Words"), hbox);
     m_thes_hyper = new TQListBox(grpbox_hyper);
 
-    grpbox_hypo = new TQGroupBox( 1, Qt::Horizontal, i18n("More Specific Words"), hbox);
+    grpbox_hypo = new TQGroupBox( 1, TQt::Horizontal, i18n("More Specific Words"), hbox);
     m_thes_hypo = new TQListBox(grpbox_hypo);
 
     // single click -- keep display unambiguous by removing other selections:
     
-    connect(m_thes_syn, TQT_SIGNAL(clicked(TQListBoxItem *)), m_thes_hyper, TQT_SLOT(clearSelection()));
-    connect(m_thes_syn, TQT_SIGNAL(clicked(TQListBoxItem *)), m_thes_hypo, TQT_SLOT(clearSelection()));
-    connect(m_thes_syn, TQT_SIGNAL(selectionChanged(TQListBoxItem *)),
-        this, TQT_SLOT(slotSetReplaceTerm(TQListBoxItem *)));
+    connect(m_thes_syn, TQ_SIGNAL(clicked(TQListBoxItem *)), m_thes_hyper, TQ_SLOT(clearSelection()));
+    connect(m_thes_syn, TQ_SIGNAL(clicked(TQListBoxItem *)), m_thes_hypo, TQ_SLOT(clearSelection()));
+    connect(m_thes_syn, TQ_SIGNAL(selectionChanged(TQListBoxItem *)),
+        this, TQ_SLOT(slotSetReplaceTerm(TQListBoxItem *)));
 
-    connect(m_thes_hyper, TQT_SIGNAL(clicked(TQListBoxItem *)), m_thes_syn, TQT_SLOT(clearSelection()));
-    connect(m_thes_hyper, TQT_SIGNAL(clicked(TQListBoxItem *)), m_thes_hypo, TQT_SLOT(clearSelection()));
-    connect(m_thes_hyper, TQT_SIGNAL(selectionChanged(TQListBoxItem *)),
-        this, TQT_SLOT(slotSetReplaceTerm(TQListBoxItem *)));
+    connect(m_thes_hyper, TQ_SIGNAL(clicked(TQListBoxItem *)), m_thes_syn, TQ_SLOT(clearSelection()));
+    connect(m_thes_hyper, TQ_SIGNAL(clicked(TQListBoxItem *)), m_thes_hypo, TQ_SLOT(clearSelection()));
+    connect(m_thes_hyper, TQ_SIGNAL(selectionChanged(TQListBoxItem *)),
+        this, TQ_SLOT(slotSetReplaceTerm(TQListBoxItem *)));
 
-    connect(m_thes_hypo, TQT_SIGNAL(clicked(TQListBoxItem *)), m_thes_syn, TQT_SLOT(clearSelection()));
-    connect(m_thes_hypo, TQT_SIGNAL(clicked(TQListBoxItem *)), m_thes_hyper, TQT_SLOT(clearSelection()));
-    connect(m_thes_hypo, TQT_SIGNAL(selectionChanged(TQListBoxItem *)),
-        this, TQT_SLOT(slotSetReplaceTerm(TQListBoxItem *)));
+    connect(m_thes_hypo, TQ_SIGNAL(clicked(TQListBoxItem *)), m_thes_syn, TQ_SLOT(clearSelection()));
+    connect(m_thes_hypo, TQ_SIGNAL(clicked(TQListBoxItem *)), m_thes_hyper, TQ_SLOT(clearSelection()));
+    connect(m_thes_hypo, TQ_SIGNAL(selectionChanged(TQListBoxItem *)),
+        this, TQ_SLOT(slotSetReplaceTerm(TQListBoxItem *)));
 
     // double click:
-    connect(m_thes_syn, TQT_SIGNAL(selected(const TQString &)),
-        this, TQT_SLOT(slotFindTerm(const TQString &)));
-    connect(m_thes_hyper, TQT_SIGNAL(selected(const TQString &)),
-        this, TQT_SLOT(slotFindTerm(const TQString &)));
-    connect(m_thes_hypo, TQT_SIGNAL(selected(const TQString &)),
-        this, TQT_SLOT(slotFindTerm(const TQString &)));
+    connect(m_thes_syn, TQ_SIGNAL(selected(const TQString &)),
+        this, TQ_SLOT(slotFindTerm(const TQString &)));
+    connect(m_thes_hyper, TQ_SIGNAL(selected(const TQString &)),
+        this, TQ_SLOT(slotFindTerm(const TQString &)));
+    connect(m_thes_hypo, TQ_SIGNAL(selected(const TQString &)),
+        this, TQ_SLOT(slotFindTerm(const TQString &)));
 
     //
     // WordNet Tab
@@ -171,18 +171,18 @@ Thesaurus::Thesaurus(TQObject* parent, const char* name, const TQStringList &)
 
     m_combobox = new TQComboBox(vbox2);
     m_combobox->setEditable(false);
-    connect(m_combobox, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotFindTerm()));
+    connect(m_combobox, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotFindTerm()));
 
     m_resultbox = new TQTextBrowser(vbox2);
     m_resultbox->setTextFormat(TQt::RichText);
     // TODO?: m_resultbox->setMimeSourceFactory(...); to avoid warning
-    connect(m_resultbox, TQT_SIGNAL(linkClicked(const TQString &)),
-        this, TQT_SLOT(slotFindTerm(const TQString &)));
+    connect(m_resultbox, TQ_SIGNAL(linkClicked(const TQString &)),
+        this, TQ_SLOT(slotFindTerm(const TQString &)));
 
     // Connect for the history box
     m_edit->setTrapReturnKey(true);        // Do not use Return as default key...
-    connect(m_edit, TQT_SIGNAL(returnPressed(const TQString&)), this, TQT_SLOT(slotFindTerm(const TQString&)));
-    connect(m_edit, TQT_SIGNAL(activated(int)), this, TQT_SLOT(slotGotoHistory(int)));
+    connect(m_edit, TQ_SIGNAL(returnPressed(const TQString&)), this, TQ_SLOT(slotFindTerm(const TQString&)));
+    connect(m_edit, TQ_SIGNAL(activated(int)), this, TQ_SLOT(slotGotoHistory(int)));
 
     TQHBoxLayout *row2 = new TQHBoxLayout( m_top_layout );
     m_replace = new KLineEdit(m_page);
@@ -200,19 +200,19 @@ Thesaurus::Thesaurus(TQObject* parent, const char* name, const TQStringList &)
     
     // calling the 'wn' binary
     m_wnproc = new TDEProcess;
-    connect(m_wnproc, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(wnExited(TDEProcess*)));
-    connect(m_wnproc, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
-        this, TQT_SLOT(receivedWnStdout(TDEProcess*, char*, int)));
-    connect(m_wnproc, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
-        this, TQT_SLOT(receivedWnStderr(TDEProcess*, char*, int)));
+    connect(m_wnproc, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(wnExited(TDEProcess*)));
+    connect(m_wnproc, TQ_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+        this, TQ_SLOT(receivedWnStdout(TDEProcess*, char*, int)));
+    connect(m_wnproc, TQ_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+        this, TQ_SLOT(receivedWnStderr(TDEProcess*, char*, int)));
 
     // grep'ing the text file
     m_thesproc = new TDEProcess;
-    connect(m_thesproc, TQT_SIGNAL(processExited(TDEProcess*)), this, TQT_SLOT(thesExited(TDEProcess*)));
-    connect(m_thesproc, TQT_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
-        this, TQT_SLOT(receivedThesStdout(TDEProcess*, char*, int)));
-    connect(m_thesproc, TQT_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
-        this, TQT_SLOT(receivedThesStderr(TDEProcess*, char*, int)));
+    connect(m_thesproc, TQ_SIGNAL(processExited(TDEProcess*)), this, TQ_SLOT(thesExited(TDEProcess*)));
+    connect(m_thesproc, TQ_SIGNAL(receivedStdout(TDEProcess*,char*,int)),
+        this, TQ_SLOT(receivedThesStdout(TDEProcess*, char*, int)));
+    connect(m_thesproc, TQ_SIGNAL(receivedStderr(TDEProcess*,char*,int)),
+        this, TQ_SLOT(receivedThesStderr(TDEProcess*, char*, int)));
 
 }
 
